# cijoe: Tools for systems development and testing

[![Build Status](https://travis-ci.org/safl/cijoe.svg?branch=master)](https://travis-ci.org/safl/cijoe)

[![Documentation Status](https://readthedocs.org/projects/cijoe/badge/?version=latest)](https://cijoe.readthedocs.io/en/latest/?badge=latest)

Documentation is available here: http://cijoe.readthedocs.io/
